@@ -6,7 +6,7 @@ from pytest_blender.run_pytest import get_blender_binary_path_python
 from pytest_blender.utils import which_blender_by_os
 
 
-__description__ = "Show a Blender builtin Python interpreter location."
+__description__ = "Show a Blender's builtin Python interpreter location."
 
 
 def build_parser():
@@ -23,7 +23,7 @@ def build_parser():
         dest="blender_executable",
         nargs=1,
         default=which_blender_by_os,
-        help="Blender executable location.",
+        help="Custom Blender executable location for 'pytest-blender' plugin.",
     )
     return parser
 
@@ -45,7 +45,8 @@ def parse_args(args):
 
 def run(args):
     opts = parse_args(args)
-    sys.stdout.write(f"{get_blender_binary_path_python(opts.blender_executable)}\n")
+    blender_python = get_blender_binary_path_python(opts.blender_executable)
+    sys.stdout.write(f"{blender_python}\n")
 
     return 0
 
