@@ -24,15 +24,43 @@ def _join(value):
         return join(value)
 
 
-# this function can't be in 'utils'
-def get_blender_binary_path_python(blender_executable):
+def _parse_version(version_string):
+    return tuple(int(i) for i in version_string.split(".") if i.isdigit())
+
+
+def get_blender_binary_path_python(blender_executable, blend_version=None):
+    """Get Blender's Python executable location.
+
+    This function can't be in utils because the module is not loaded from
+    Blender (current script is executed inside Blender's Python executable).
+
+    Parameters
+    ----------
+
+    blender_executable : str
+      Blender's executable location.
+
+    Returns
+    -------
+
+    str: Blender's Python executable path.
+    """
+    if blend_version is None:
+        blend_version = get_blender_version(blender_executable)
+    python_expr = (
+        "import sys;print(sys.executable);"
+        if _parse_version(blend_version) >= (2, 91)
+        else "import bpy;print(bpy.app.binary_path_python)"
+    )
+
     stdout = subprocess.check_output(
         [
             blender_executable,
             "-b",
             "--python-expr",
-            "import bpy;print(bpy.app.binary_path_python)",
-        ]
+            python_expr,
+        ],
+        stderr=subprocess.STDOUT,
     )
 
     blender_python_path = None
@@ -43,6 +71,21 @@ def get_blender_binary_path_python(blender_executable):
     return blender_python_path
 
 
+def get_blender_version(blender_executable):
+    """Get Blender's version goving its executable location.
+
+    blender_executable : str
+      Blender's executable location.
+
+    Returns
+    -------
+
+    str: Blender's version.
+    """
+    version_stdout = subprocess.check_output([blender_executable, "--version"])
+    return version_stdout.decode("utf-8").splitlines()[0].split(" ")[1]
+
+
 def main():
     raw_argv = shlex.split(_join(sys.argv).split(" -- ")[1:][0])
 
@@ -50,67 +93,91 @@ def main():
     argv = ["-p", "no:pytest-blender"]
 
     # parse Blender executable location, propagated from hook
-    blender_executable, _inside_bexec_arg = (None, None)
+    _blender_executable, _inside_bexec_arg = (None, None)
     for arg in raw_argv:
         if arg == "--pytest-blender-executable":
             _inside_bexec_arg = True
             continue
         elif _inside_bexec_arg:
-            blender_executable = arg
+            _blender_executable = arg
             _inside_bexec_arg = False
             continue
         argv.append(arg)
 
     class PytestBlenderPlugin:
+        """Pytest plugin used by pytest-blender.
+
+        Injects all the fixtures in the Blender's PyTest session of the user.
+        """
+
         def _blender_python_executable(self, request):
-            blender_python_executable = request.config.cache.get(
-                "pytest-blender/blender-python-executable",
-                None,
-            )
-            if blender_python_executable is None:
-                blender_python_executable = get_blender_binary_path_python(
-                    blender_executable,
-                )
-                request.config.cache.set(
+            response = None
+
+            # if pytest is executed without cache provider, the 'cache'
+            #   attribute will not be available (-p no:cacheprovider)
+            if hasattr(request.config, "cache"):
+                response = request.config.cache.get(
                     "pytest-blender/blender-python-executable",
-                    blender_python_executable,
+                    None,
                 )
-            return blender_python_executable
+
+            if response is None:
+                response = get_blender_binary_path_python(
+                    _blender_executable,
+                    blend_version=self._blender_version(request),
+                )
+                if hasattr(request.config, "cache"):
+                    request.config.cache.set(
+                        "pytest-blender/blender-python-executable",
+                        response,
+                    )
+            return response
 
         @pytest.fixture
         def blender_executable(self):
-            return blender_executable
+            """Get the executable of the current Blender's session."""
+            return _blender_executable
 
         @pytest.fixture
         def blender_python_executable(self, request):
+            """Get the executable of the current Blender's Python session."""
             return self._blender_python_executable(request)
 
+        def _blender_version(self, request):
+            response = None
+
+            if hasattr(request.config, "cache"):
+                response = request.config.cache.get(
+                    "pytest-blender/blender-version",
+                    None,
+                )
+
+            if response is None:
+                response = get_blender_version(_blender_executable)
+                if hasattr(request.config, "cache"):
+                    request.config.cache.set(
+                        "pytest-blender/blender-version",
+                        response,
+                    )
+            return response
+
         @pytest.fixture
         def blender_version(self, request):
-            blender_version = request.config.cache.get(
-                "pytest-blender/blender-version",
-                None,
-            )
-            if blender_version is None:
-                version_stdout = subprocess.check_output(
-                    [blender_executable, "--version"]
-                )
-                blender_version = (
-                    version_stdout.decode("utf-8").splitlines()[0].split(" ")[1]
-                )
-                request.config.cache.set(
-                    "pytest-blender/blender-version",
-                    blender_version,
-                )
-            return blender_version
+            """Get the Blender version of the current session."""
+            return self._blender_version(request)
 
         @pytest.fixture
         def blender_python_version(self, request):
-            blender_python_version = request.config.cache.get(
-                "pytest-blender/blender-python-version",
-                None,
-            )
-            if blender_python_version is None:
+            """Get the version of the Blender's Python executable."""
+            response = None
+
+            if hasattr(request.config, "cache"):
+                response = request.config.cache.get(
+                    "pytest-blender/blender-python-version",
+                    None,
+                )
+
+            if response is None:
                 blender_python_executable = self._blender_python_executable(request)
                 blender_python_version_stdout = subprocess.check_output(
                     [
@@ -118,22 +185,29 @@ def main():
                         "--version",
                     ]
                 )
-                blender_python_version = (
+                response = (
                     blender_python_version_stdout.decode("utf-8")
                     .splitlines()[0]
                     .split(" ")[1]
                 )
-                request.config.cache.set(
-                    "pytest-blender/blender-python-version",
-                    blender_python_version,
-                )
-            return blender_python_version
+                if hasattr(request.config, "cache"):
+                    request.config.cache.set(
+                        "pytest-blender/blender-python-version",
+                        response,
+                    )
+            return response
 
         @pytest.fixture(scope="session")
         def install_addons_from_dir(self, request):
+            """Install Blender's addons from directory.
+
+            Installs a set of Blender's addons into the current Blender's
+            session specifying the names of the addons to be installed.
+            """
+
             def _install_addons_from_dir(
                 addons_dir,
-                addon_module_names,
+                addon_module_names=None,
                 save_userpref=True,
                 default_set=True,
                 persistent=True,
@@ -142,8 +216,23 @@ def main():
                 import addon_utils  # noqa F401
                 import bpy  # noqa F401
 
+                if addon_module_names is None:
+                    addon_module_names = [
+                        fname.rstrip(".py")
+                        for fname in os.listdir(addons_dir)
+                        if not fname.startswith("__")
+                    ]
+                    if not addon_module_names:
+                        raise ValueError(
+                            f"Any addons found in '{addons_dir}' directory."
+                        )
+                elif not addon_module_names:
+                    raise ValueError("You need to pass at least one addon to install.")
+
                 for addon_module_name in addon_module_names:
-                    addon_filepath = os.path.join(addons_dir, f"{addon_module_name}.py")
+                    addon_filepath = os.path.join(
+                        addons_dir, f"{addon_module_name.rstrip('.py')}.py"
+                    )
                     bpy.ops.preferences.addon_install(filepath=addon_filepath, **kwargs)
                     addon_utils.enable(
                         addon_module_name,
@@ -153,10 +242,14 @@ def main():
                 if save_userpref:
                     bpy.ops.wm.save_userpref()
 
+                return addon_module_names
+
             return _install_addons_from_dir
 
         @pytest.fixture(scope="session")
         def disable_addons(self, request):
+            """Disable installed addons in the current Blender's session."""
+
             def _disable_addons(
                 addon_module_names,
                 save_userpref=True,
